@@ -16,7 +16,7 @@ use FileHandle ();
 use File::Basename ();
 use File::Path ();
 use vars qw($VERSION);
-$VERSION = substr q$Revision: 1.28 $, 10;
+$VERSION = substr q$Revision: 1.31 $, 10;
 
 =head1 NAME
 
@@ -37,11 +37,14 @@ file. Nothing special.
 sub init {
     my($configpm) = @_;
     use Config;
-    require CPAN::Nox;
+    unless ($CPAN::VERSION) {
+	require CPAN::Nox;
+    }
     eval {require CPAN::Config;};
     $CPAN::Config ||= {};
     local($/) = "\n";
     local($\) = "";
+    local($|) = 1;
 
     my($ans,$default,$local,$cont,$url,$expected_size);
     
@@ -49,7 +52,7 @@ sub init {
     # Files, directories
     #
 
-    print qq{
+    print qq[
 
 CPAN is the world-wide archive of perl resources. It consists of about
 100 sites that all replicate the same contents all around the globe.
@@ -61,7 +64,7 @@ If you do not want to enter a dialog now, you can answer 'no' to this
 question and I\'ll try to autoconfigure. (Note: you can revisit this
 dialog anytime later by typing 'o conf init' at the cpan prompt.)
 
-};
+];
 
     my $manual_conf =
 	ExtUtils::MakeMaker::prompt("Are you ready for manual configuration?",
@@ -150,6 +153,20 @@ with all the intermediate files?
     # XXX This the time when we refetch the index files (in days)
     $CPAN::Config->{'index_expire'} = 1;
 
+    print qq{
+
+By default, each time the CPAN module is started, cache scanning
+is performed to keep the cache size in sync. To prevent from this, 
+disable the cache scanning with 'never'.
+
+};
+
+    $default = $CPAN::Config->{scan_cache} || 'atstart';
+    do {
+        $ans = prompt("Perform cache scanning (atstart or never)?", $default);
+    } while ($ans ne 'atstart' && $ans ne 'never');
+    $CPAN::Config->{scan_cache} = $ans;
+
     #
     # External programs
     #
@@ -165,30 +182,32 @@ those.
 
     my(@path) = split /$Config{'path_sep'}/, $ENV{'PATH'};
     my $progname;
-    for $progname (qw/gzip tar unzip make lynx ncftp ftp/){
+    for $progname (qw/gzip tar unzip make lynx ncftpget ncftp ftp/){
       my $progcall = $progname;
-	my $path = $CPAN::Config->{$progname} 
-	        || $Config::Config{$progname}
-		|| "";
-	if (MM->file_name_is_absolute($path)) {
-	  # testing existence is not good enough, some have these exe
-	  # extensions
+      # we don't need ncftp if we have ncftpget
+      next if $progname eq "ncftp" && $CPAN::Config->{ncftpget} gt " ";
+      my $path = $CPAN::Config->{$progname} 
+	  || $Config::Config{$progname}
+	      || "";
+      if (MM->file_name_is_absolute($path)) {
+	# testing existence is not good enough, some have these exe
+	# extensions
 
-	  # warn "Warning: configured $path does not exist\n" unless -e $path;
-	  # $path = "";
-	} else {
-	    $path = '';
-	}
-	unless ($path) {
-	  # e.g. make -> nmake
-	  $progcall = $Config::Config{$progname} if $Config::Config{$progname};
-	}
+	# warn "Warning: configured $path does not exist\n" unless -e $path;
+	# $path = "";
+      } else {
+	$path = '';
+      }
+      unless ($path) {
+	# e.g. make -> nmake
+	$progcall = $Config::Config{$progname} if $Config::Config{$progname};
+      }
 
-	$path ||= find_exe($progcall,[@path]);
-	warn "Warning: $progcall not found in PATH\n" unless
-	    $path; # not -e $path, because find_exe already checked that
-	$ans = prompt("Where is your $progname program?",$path) || $path;
-	$CPAN::Config->{$progname} = $ans;
+      $path ||= find_exe($progcall,[@path]);
+      warn "Warning: $progcall not found in PATH\n" unless
+	  $path; # not -e $path, because find_exe already checked that
+      $ans = prompt("Where is your $progname program?",$path) || $path;
+      $CPAN::Config->{$progname} = $ans;
     }
     my $path = $CPAN::Config->{'pager'} || 
 	$ENV{PAGER} || find_exe("less",[@path]) || 
@@ -201,6 +220,7 @@ those.
 	$path = "";
     }
     $path ||= $ENV{SHELL};
+    $path =~ s,\\,/,g if $^O eq 'os2';	# Cosmetic only
     $ans = prompt("What is your favorite shell?",$path);
     $CPAN::Config->{'shell'} = $ans;
 
@@ -319,7 +339,7 @@ sub find_exe {
     #warn "in find_exe exe[$exe] path[@$path]";
     for $dir (@$path) {
 	my $abs = MM->catfile($dir,$exe);
-	if (MM->maybe_command($abs)) {
+	if (($abs = MM->maybe_command($abs))) {
 	    return $abs;
 	}
     }
@@ -372,7 +392,8 @@ file:, ftp: or http: URL, or "q" to finish selecting.
     my $other;
     $ans = $other = "";
     my(%seen);
-    
+
+    local($SIG{PIPE}) = 'IGNORE';
     my $pipe = -t *STDIN ? "| $CPAN::Config->{'pager'}" : ">/dev/null";
     while () {
 	my(@valid,$previous_best);
